@@ -62,6 +62,7 @@ public class BOINCActivity extends TabActivity {
 	private Boolean mIsBound = false;
 	
 	private TabHost tabHost;
+	private Resources res;
 	
 	// dummy jni to trigger PlayStore filter for CPU architecture
 	static{
@@ -109,6 +110,10 @@ public class BOINCActivity extends TabActivity {
         
         // adapt to custom title bar
         getWindow().setFeatureInt(Window.FEATURE_CUSTOM_TITLE, R.layout.title_bar);
+        
+        // get tab host and setup layout
+    	res = getResources();
+    	tabHost = getTabHost();
         setupTabLayout();
     }
     
@@ -221,19 +226,15 @@ public class BOINCActivity extends TabActivity {
      * which tabs should be set up is defined in resources file: /res/values/configuration.xml
      */
     private void setupTabLayout() {
-    	
-    	Resources res = getResources();
-    	tabHost = getTabHost();
-        
     	// set tabs
     	if(res.getBoolean(R.bool.tab_status))
     		setupTab(new TextView(this), getResources().getString(R.string.tab_status), R.drawable.icon_status_tab, StatusActivity.class);
+    	if(res.getBoolean(R.bool.tab_notices))
+    		setupTab(new TextView(this), getResources().getString(R.string.tab_notices), R.drawable.icon_notices_tab, NoticesActivity.class);
     	if(res.getBoolean(R.bool.tab_projects))
     		setupTab(new TextView(this), getResources().getString(R.string.tab_projects), R.drawable.icon_projects_tab, ProjectsActivity.class);
     	if(res.getBoolean(R.bool.tab_tasks))
     		setupTab(new TextView(this), getResources().getString(R.string.tab_tasks), R.drawable.icon_tasks_tab, TasksActivity.class);
-    	if(res.getBoolean(R.bool.tab_transfers))
-    		setupTab(new TextView(this), getResources().getString(R.string.tab_transfers), R.drawable.icon_trans_tab, TransActivity.class);
     	if(res.getBoolean(R.bool.tab_preferences))
     		setupTab(new TextView(this), getResources().getString(R.string.tab_preferences), R.drawable.icon_prefs_tab, PrefsActivity.class);
 
@@ -309,11 +310,6 @@ public class BOINCActivity extends TabActivity {
 			runMode.setIcon(R.drawable.pausew);
 		}
 		
-		// event log, show only in advanced mode
-		MenuItem eventLog = menu.findItem(R.id.event_log);
-		if(Monitor.getAppPrefs().getShowAdvanced()) eventLog.setVisible(true);
-		else eventLog.setVisible(false);
-		
 		return super.onPrepareOptionsMenu(menu);
 	}
 	
