@@ -33,7 +33,6 @@ import java.io.OutputStream;
 import java.security.MessageDigest;
 import java.security.NoSuchAlgorithmException;
 import java.util.ArrayList;
-import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Timer;
 import java.util.TimerTask;
@@ -59,12 +58,15 @@ import edu.berkeley.boinc.rpc.CcStatus;
 import edu.berkeley.boinc.rpc.DeviceStatus;
 import edu.berkeley.boinc.rpc.GlobalPreferences;
 import edu.berkeley.boinc.rpc.Message;
+import edu.berkeley.boinc.rpc.Notice;
 import edu.berkeley.boinc.rpc.Project;
 import edu.berkeley.boinc.rpc.ProjectAttachReply;
 import edu.berkeley.boinc.rpc.ProjectInfo;
 import edu.berkeley.boinc.rpc.ProjectConfig;
 import edu.berkeley.boinc.rpc.RpcClient;
 import edu.berkeley.boinc.rpc.Transfer;
+import edu.berkeley.boinc.rpc.AcctMgrRPCReply;
+import edu.berkeley.boinc.rpc.AcctMgrInfo;
 
 public class Monitor extends Service {
 	
@@ -258,7 +260,6 @@ public class Monitor extends Service {
 		installFile(clientCABundle, true, false);
 		installFile(clientConfig, true, false);
 		installFile(allProjectsList, true, false);
-		installFile(globalOverridePreferences, false, false);
     	
     	return true; 
     }
@@ -359,7 +360,8 @@ public class Monitor extends Service {
     		// wake locks and foreground enabled when Client is not suspended, therefore also during
     		// idle.
     		CcStatus status = rpc.getCcStatus();
-    		Boolean computing = (status.task_suspend_reason == BOINCDefs.SUSPEND_NOT_SUSPENDED);
+    		// treat cpu throttling as if it was computing
+    		Boolean computing = (status.task_suspend_reason == BOINCDefs.SUSPEND_NOT_SUSPENDED) || (status.task_suspend_reason == BOINCDefs.SUSPEND_REASON_CPU_THROTTLE);
     		if(Logging.VERBOSE) Log.d(Logging.TAG,"readClientStatus(): computation enabled: " + computing);
 			Monitor.getClientStatus().setWifiLock(computing);
 			Monitor.getClientStatus().setWakeLock(computing);
@@ -374,13 +376,24 @@ public class Monitor extends Service {
 				if(Logging.VERBOSE) Log.d(Logging.TAG, "readClientStatus(): screen on, get complete status");
 				CcState state = rpc.getState();
 				ArrayList<Transfer>  transfers = rpc.getFileTransfers();
+				AcctMgrInfo acctMgrInfo = rpc.getAcctMgrInfo();
 				
-				if( (status != null) && (state != null) && (state.results != null) && (state.projects != null) && (transfers != null) && (state.host_info != null)) {
-					Monitor.getClientStatus().setClientStatus(status, state.results, state.projects, transfers, state.host_info);
+				if( (status != null) && (state != null) && (state.results != null) && (state.projects != null) && (transfers != null) && (state.host_info != null) && (acctMgrInfo != null)) {
+					Monitor.getClientStatus().setClientStatus(status, state.results, state.projects, transfers, state.host_info, acctMgrInfo);
 					// Update status bar notification
 					ClientNotification.getInstance(getApplicationContext()).update();
 				} else {
-					if(Logging.ERROR) Log.e(Logging.TAG, "readClientStatus(): connection problem");
+					String nullValues = "";
+					try{
+						if(status == null) nullValues += "status,";
+						if(state == null) nullValues += "state,";
+						if(state.results == null) nullValues += "state.results,";
+						if(state.projects == null) nullValues += "state.projects,";
+						if(transfers == null) nullValues += "transfers,";
+						if(state.host_info == null) nullValues += "state.host_info,";
+						if(acctMgrInfo == null) nullValues += "acctMgrInfo,";
+					} catch (NullPointerException e) {};
+					if(Logging.ERROR) Log.e(Logging.TAG, "readClientStatus(): connection problem, null: " + nullValues);
 				}
 				
 				// check whether monitor is still intended to update, if not, skip broadcast and exit...
@@ -494,25 +507,49 @@ public class Monitor extends Service {
 	    	}
     	} catch (Exception e) {
     		if(Logging.ERROR) Log.e(Logging.TAG, "Exception: " + e.getMessage());
+    		return null;
+    	}
+
+    	String [] processLinesAr = sb.toString().split("\n");
+    	if (processLinesAr.length < 2) {
+    		if(Logging.ERROR) Log.e(Logging.TAG,"getPidForProcessName(): ps output has less than 2 lines, failure!");
+    		return null;
     	}
     	
-    	//parse output into hashmap
-    	HashMap<String,Integer> pMap = new HashMap<String, Integer>();
-    	String [] processLinesAr = sb.toString().split("\n");
-    	for(String line : processLinesAr)
-    	{
-    		Integer pid;
-    		String packageName;
-    	    String [] comps = line.split("[\\s]+");
-    	    if(comps.length != 9) {continue;}     
-    	    pid = Integer.parseInt(comps[1]);
-    	    packageName = comps[8];
-    	    pMap.put(packageName, pid);
-    	    //if(Logging.DEBUG) Log.d(Logging.TAG,"added: " + packageName + pid); 
+    	// figure out what index PID has
+    	String [] headers = processLinesAr[0].split("[\\s]+");
+    	Integer PidIndex = 1;
+    	for (int x = 0; x < headers.length; x++) {
+    		if(headers[x].equals("PID")) {
+    			PidIndex = x;
+    			continue;
+    		}
     	}
+		if(Logging.DEBUG) Log.d(Logging.TAG,"getPidForProcessName(): PID at index: " + PidIndex + " for output: " + processLinesAr[0]);
+    	
+		Integer pid = null;
+    	for(int y = 1; y < processLinesAr.length; y++) {
+    		Boolean found = false;
+    	    String [] comps = processLinesAr[y].split("[\\s]+");
+    	    for(String arg: comps) {
+    	    	if(arg.equals(processName)) {
+    	    		if(Logging.DEBUG) Log.d(Logging.TAG,"getPidForProcessName(): " + processName + " found in line: " + y);
+    	    		found = true;
+    	    	}
+    	    }
+    	    if(found) {
+	    	    try{
+	    	    	pid = Integer.parseInt(comps[PidIndex]);
+	        	    if(Logging.DEBUG) Log.d(Logging.TAG,"getPidForProcessName(): pid: " + pid); 
+	    	    }catch (NumberFormatException e) {if(Logging.ERROR) Log.e(Logging.TAG,"getPidForProcessName(): NumberFormatException for " + comps[PidIndex] + " at index: " + PidIndex);}
+	    	    continue;
+    	    }
+    	}
+    	// if not happen in ps output, not running?!
+		if(pid == null) if(Logging.DEBUG) Log.d(Logging.TAG,"getPidForProcessName(): " + processName + " not found in ps output!");
     	
     	// Find required pid
-    	return pMap.get(processName);
+    	return pid;
     }
     
     // Exit a process with OS signals SIGQUIT and SIGKILL
@@ -706,7 +743,9 @@ public class Monitor extends Service {
     // will fire clientstatuschange Broadcast updon completion
     public void forceRefresh() {
     	if(Logging.DEBUG) Log.d(Logging.TAG,"forceRefresh()");
-        updateTimer.schedule(new StatusUpdateTimerTask(), 0);
+    	try{
+    		updateTimer.schedule(new StatusUpdateTimerTask(), 0);
+    	} catch (Exception e){} // throws IllegalStateException if called after timer got cancelled, i.e. after manual shutdown
     }
     
     // exits both, UI and BOINC client. 
@@ -948,33 +987,9 @@ public class Monitor extends Service {
 		rpc.readCcConfig();
 	}
     
-	public Boolean abortTransfer(String url, String name){
-		return rpc.transferOp(RpcClient.TRANSFER_ABORT, url, name);
-	}
-	
-	public void abortTransferAsync(String url, String name){
-		if(Logging.DEBUG) Log.d(Logging.TAG, "abortTransferAsync");
-		String[] param = new String[2];
-		param[0] = url;
-		param[1] = name;
-		(new TransferAbortAsync()).execute(param);
-	}
-    
 	public Boolean projectOperation(int operation, String url){
 		return rpc.projectOp(operation, url);
 	}
-    
-	public Boolean retryTransfer(String url, String name){
-		return rpc.transferOp(RpcClient.TRANSFER_RETRY, url, name);
-	}
-	
-	public void retryTransferAsync(String url, String name){
-		if(Logging.DEBUG) Log.d(Logging.TAG, "retryTransferAsync");
-		String[] param = new String[2];
-		param[0] = url;
-		param[1] = name;
-		(new TransferRetryAsync()).execute(param);
-	}
 
 	// executes specified operation on result
 	// e.g. RpcClient.RESULT_SUSPEND, RpcClient.RESULT_RESUME, RpcClient.RESULT_ABORT
@@ -982,8 +997,13 @@ public class Monitor extends Service {
 		return rpc.resultOp(operation, url, name);
 	}
 	
-	public Boolean transferOperation(String url, String name, int operation) {
-		return rpc.transferOp(operation, url, name);
+	public Boolean transferOperation(ArrayList<Transfer> transfers, int operation) {
+		Boolean success = true;
+		for (Transfer transfer: transfers) {
+			success = success && rpc.transferOp(operation, transfer.project_url, transfer.name);
+			if(Logging.DEBUG) Log.d(Logging.TAG, "transfer: " + transfer.name + " " + success);
+		}
+		return success;
 	}
 	
 	public AccountOut createAccount(String url, String email, String userName, String pwd, String teamName) {
@@ -1027,6 +1047,119 @@ public class Monitor extends Service {
     	return auth;
 	}
 	
+	public AcctMgrRPCReply addAcctMgr(String url, String userName, String pwd) {
+		AcctMgrRPCReply reply = null;
+    	Boolean success = rpc.acctMgrRPC(url, userName, pwd); //asynchronous call to attach account manager
+    	if(success) { //only continue if rpc command did not fail
+    		// verify success of acctMgrRPC with poll function
+    		Integer counter = 0;
+    		Integer sleepDuration = 500; //in milliseconds
+    		Integer maxLoops = maxDuration / sleepDuration;
+    		Boolean loop = true;
+    		while(loop && (counter < maxLoops)) {
+    			loop = false;
+    			try {
+    				Thread.sleep(sleepDuration);
+    			} catch (Exception e) {}
+    			counter ++;
+    			reply = rpc.acctMgrRPCPoll();
+    			if(reply == null) {
+    				if(Logging.DEBUG) Log.d(Logging.TAG,"error in rpc.addAcctMgr.");
+    				return null;
+    			}
+    			if (reply.error_num == -204) {
+    				loop = true; //no result yet, keep looping
+    			}
+    			else {
+    				//final result ready
+    				if(reply.error_num == 0) if(Logging.DEBUG) Log.d(Logging.TAG, "account manager attach successful.");
+    				else if(Logging.DEBUG) Log.d(Logging.TAG, "account manager attach failed, error: " + reply.error_num);
+    			}
+    		}
+    	} else {if(Logging.DEBUG) Log.d(Logging.TAG,"rpc.acctMgrRPC returned false.");}
+    	return reply;
+	}
+	
+	// RPC sequence copied by implementation of MAC manager
+	public Boolean synchronizeAcctMgr(String url) {
+
+	// 1st get_project_config for account manager url
+		Boolean success = false;
+		ProjectConfig reply = null;
+		success = rpc.getProjectConfig(url);
+    	if(success) { //only continue if rpc command did not fail
+    		// verify success of getProjectConfig with poll function
+    		Integer counter = 0;
+    		Integer sleepDuration = 500; //in milliseconds
+    		Integer maxLoops = maxDuration / sleepDuration;
+    		Boolean loop = true;
+    		while(loop && (counter < maxLoops)) {
+    			loop = false;
+    			try {
+    				Thread.sleep(sleepDuration);
+    			} catch (Exception e) {}
+    			counter ++;
+    			reply = rpc.getProjectConfigPoll();
+    			if(reply == null) {
+    				if(Logging.DEBUG) Log.d(Logging.TAG,"error in rpc.getProjectConfig.");
+    				return false;
+    			}
+    			if (reply.error_num == -204) {
+    				loop = true; //no result yet, keep looping
+    			}
+    			else {
+    				//final result ready
+    				if(reply.error_num == 0) if(Logging.DEBUG) Log.d(Logging.TAG, "getting project config for account manager synchronization successful.");
+    				else  {
+    					if(Logging.DEBUG) Log.d(Logging.TAG, "getting project config for account manager synchronization failed, error: " + reply.error_num);
+    					return false;
+    				}
+    			}
+    		}
+    	} else {if(Logging.DEBUG) Log.d(Logging.TAG,"rpc.getProjectConfig returned false.");}
+		
+    // 2nd acct_mgr_rpc with <use_config_file/>
+		success = false;
+		AcctMgrRPCReply reply2 = null;
+    	success = rpc.acctMgrRPC(); //asynchronous call to synchronize account manager
+    	if(success) { //only continue if rpc command did not fail
+    		// verify success of acctMgrRPC with poll function
+    		Integer counter = 0;
+    		Integer sleepDuration = 500; //in milliseconds
+    		Integer maxLoops = maxDuration / sleepDuration;
+    		Boolean loop = true;
+    		while(loop && (counter < maxLoops)) {
+    			loop = false;
+    			try {
+    				Thread.sleep(sleepDuration);
+    			} catch (Exception e) {}
+    			counter ++;
+    			reply2 = rpc.acctMgrRPCPoll();
+    			if(reply2 == null) {
+    				if(Logging.DEBUG) Log.d(Logging.TAG,"error in rpc.addAcctMgr.");
+    				return false;
+    			}
+    			if (reply2.error_num == -204) {
+    				loop = true; //no result yet, keep looping
+    			}
+    			else {
+    				//final result ready
+    				if(reply2.error_num == 0) if(Logging.DEBUG) Log.d(Logging.TAG, "account manager synchronization successful.");
+    				else {
+    					if(Logging.DEBUG) Log.d(Logging.TAG, "account manager synchronization failed, error: " + reply2.error_num);
+    					return false;
+    				}
+    			}
+    		}
+    	} else {if(Logging.DEBUG) Log.d(Logging.TAG,"rpc.acctMgrRPC returned false.");}
+		
+		return false;
+	}
+	
+	public AcctMgrInfo getAcctMgrInfo() {
+		return rpc.getAcctMgrInfo();
+	}
+	
 	// returns given number of client messages, older than provided seqNo
 	// if seqNo <= 0 initial data retrieval
 	public ArrayList<Message> getEventLogMessages(int seqNo, int number) {
@@ -1061,6 +1194,22 @@ public class Monitor extends Service {
 		return rpc.getMessages(seqNo);
 	}
 	
+	// returns notices
+	public ArrayList<Notice> getNotices() {
+		return rpc.getNotices(0);
+	}
+	
+	// returns notices sent by the project server / scheduler
+	// i.e. when scheduler request does not satisfy minimal requirements
+	public ArrayList<Notice> getServerNotices() {
+		ArrayList<Notice> allNotices = rpc.getNotices(0);
+		ArrayList<Notice> serverNotices = new ArrayList<Notice>();
+		for(Notice notice: allNotices) {
+			if(notice.isServerNotice) serverNotices.add(notice);
+		}
+		return serverNotices;
+	}
+	
 	// updates the client status via rpc
 	// reports current device status to the client via rpc
 	//
@@ -1071,64 +1220,6 @@ public class Monitor extends Service {
 			updateStatus();
 		}
 	}
-
-	private final class TransferAbortAsync extends AsyncTask<String,String,Boolean> {
-		
-		private String url;
-		private String name;
-		
-		@Override
-		protected Boolean doInBackground(String... params) {
-			this.url = params[0];
-			this.name = params[0];
-			publishProgress("doInBackground() - TransferAbortAsync url: " + url + " Name: " + name);
-			
-			Boolean abort = rpc.transferOp(RpcClient.TRANSFER_ABORT, url, name);
-			if(abort) {
-				if(Logging.DEBUG) Log.d(Logging.TAG, "successful.");
-			}
-			return abort;
-		}
-		
-		@Override
-		protected void onPostExecute(Boolean success) {
-			forceRefresh();
-		}
-
-		@Override
-		protected void onProgressUpdate(String... arg0) {
-			if(Logging.DEBUG) Log.d(Logging.TAG, "onProgressUpdate - " + arg0[0]);
-		}
-	}
-
-	private final class TransferRetryAsync extends AsyncTask<String,String,Boolean> {
-		
-		private String url;
-		private String name;
-		
-		@Override
-		protected Boolean doInBackground(String... params) {
-			this.url = params[0];
-			this.name = params[1];
-			publishProgress("doInBackground() - TransferRetryAsync url: " + url + " Name: " + name);
-			
-			Boolean retry = rpc.transferOp(RpcClient.TRANSFER_RETRY, url, name);
-			if(retry) {
-				publishProgress("successful.");
-			}
-			return retry;
-		}
-		
-		@Override
-		protected void onPostExecute(Boolean success) {
-			forceRefresh();
-		}
-
-		@Override
-		protected void onProgressUpdate(String... arg0) {
-			if(Logging.DEBUG) Log.d(Logging.TAG, "onProgressUpdate - " + arg0[0]);
-		}
-	}
 	
 	// broadcast receiver to detect changes to screen on or off
 	// used to adapt ClientMonitorAsync bahavior
