@@ -65,13 +65,16 @@ public class RpcClient {
 	public static final int PROJECT_DETACH	= 6;
 	public static final int PROJECT_RESET	= 7;
 
-	public static final int RESULT_SUSPEND  = 1;
-	public static final int RESULT_RESUME   = 2;
-	public static final int RESULT_ABORT    = 3;
-
-	public static final int TRANSFER_RETRY  = 1;
-	public static final int TRANSFER_ABORT  = 2;
+	public static final int RESULT_SUSPEND  = 10;
+	public static final int RESULT_RESUME   = 11;
+	public static final int RESULT_ABORT    = 12;
 
+	public static final int TRANSFER_RETRY  = 20;
+	public static final int TRANSFER_ABORT  = 21;
+	
+	public static final int MGR_DETACH = 30;
+	public static final int MGR_SYNC = 31;
+	
 	private Socket mSocket;
 	private OutputStreamWriter mOutput;
 	private InputStream mInput;
@@ -507,6 +510,36 @@ public class RpcClient {
 			return null;
 		}
 	}
+	
+	/**
+	 * Performs get_notices PRC towards BOINC client
+	 * Returns client messages that are more recent than seqNo param
+	 * @return List of Notices
+	 */
+	public synchronized ArrayList<Notice> getNotices(int seqNo) {
+		mLastErrorMessage = null;
+		try {
+			String request;
+			if (seqNo == 0) {
+				// get all notices
+				request = "<get_notices/>\n";
+			}
+			else {
+				request =
+					"<get_notices>\n" +
+					" <seqno>" + seqNo + "</seqno>\n" +
+					"</get_notices>\n";
+			}
+			sendRequest(request);
+			ArrayList<Notice> notices = NoticesParser.parse(receiveReply());
+			if(notices == null) notices = new ArrayList<Notice>(); // do not return null
+			return notices;
+		}
+		catch (IOException e) {
+			if(Logging.WARNING) Log.w(Logging.TAG, "error in getMessages()", e);
+			return new ArrayList<Notice>();
+		}
+	}
 
 	/**
 	 * Performs get_project_status RPC towards BOINC client
@@ -870,6 +903,89 @@ public class RpcClient {
 		}
 	}
 	
+	/**
+	 * performs acct_mgr_rpc towards client
+	 * attaches account manager to client
+	 * requires polling of status
+	 * @param url
+	 * @param name
+	 * @param passwd
+	 * @return success
+	 */
+	public synchronized boolean acctMgrRPC(String url, String name, String passwd) {
+		try {
+			mRequest.setLength(0);
+			mRequest.append("<acct_mgr_rpc>\n   <url>");
+			mRequest.append(url);
+			mRequest.append("</url>\n   <name>");
+			mRequest.append(name);
+			mRequest.append("</name>\n   <password>");
+			mRequest.append(passwd);
+			mRequest.append("</password>\n</acct_mgr_rpc>\n");
+
+			sendRequest(mRequest.toString());
+			SimpleReplyParser parser = SimpleReplyParser.parse(receiveReply());
+			mLastErrorMessage = parser.getErrorMessage();
+			return parser.result();
+		} catch (IOException e) {
+			if(Logging.WARNING) Log.w(Logging.TAG, "error in acctMgrRPC()", e);
+			return false;
+		}
+	}
+	
+	/**
+	 * performs acct_mgr_rpc with <use_config_file/> instead of login information
+	 * @return success
+	 */
+	public synchronized boolean acctMgrRPC() {
+		try {
+			mRequest.setLength(0);
+			mRequest.append("<acct_mgr_rpc>\n<use_config_file/>\n</acct_mgr_rpc>\n");
+
+			sendRequest(mRequest.toString());
+			SimpleReplyParser parser = SimpleReplyParser.parse(receiveReply());
+			mLastErrorMessage = parser.getErrorMessage();
+			return parser.result();
+		} catch (IOException e) {
+			if(Logging.WARNING) Log.w(Logging.TAG, "error in acctMgrRPC()", e);
+			return false;
+		}
+	}
+
+	/**
+	 * performs acct_mgr_rpc_poll towards client
+	 * polls status of acct_mgr_rpc
+	 * @return status class AcctMgrRPCReply
+	 */
+	public synchronized AcctMgrRPCReply acctMgrRPCPoll() {
+		try {
+			mRequest.setLength(0);
+			mRequest.append("<acct_mgr_rpc_poll/>");
+
+			sendRequest(mRequest.toString());
+			return AcctMgrRPCReplyParser.parse(receiveReply());
+		} catch (IOException e) {
+			if(Logging.WARNING) Log.w(Logging.TAG, "error in acctMgrRPCPoll()", e);
+			return null;
+		}
+	}
+	
+	/**
+	 * performs acct_mgr_info towards client
+	 * @return status class AcctMgrInfo
+	 */
+	public synchronized AcctMgrInfo getAcctMgrInfo() {
+		mLastErrorMessage = null;
+		try {
+			sendRequest("<acct_mgr_info/>\n");
+			return AcctMgrInfoParser.parse(receiveReply());
+		}
+		catch (IOException e) {
+			if(Logging.WARNING) Log.w(Logging.TAG, "error in getAcctMgrInfo()", e);
+			return null;
+		}
+	}
+	
 	public synchronized boolean getProjectConfig(String url) {
 		try {
 			mRequest.setLength(0);
