@@ -23,11 +23,12 @@
 #include <vector>
 #endif
 
-#include "client_types.h"
-#include "common_defs.h"
 #include "app_ipc.h"
+#include "common_defs.h"
 #include "procinfo.h"
 
+#include "client_types.h"
+
 #define ABORT_TIMEOUT   15
     // if we send app <abort> request, wait this long before killing it.
     // This gives it time to download symbol files (which can be several MB)
@@ -186,7 +187,7 @@ struct ACTIVE_TASK {
 
     int current_disk_usage(double&);
         // disk used by output files and temp files of this task
-    void get_free_slot(RESULT*);
+    int get_free_slot(RESULT*);
     int start(bool test=false);         // start a process
 
     // Termination stuff.
