@@ -38,6 +38,7 @@
 #endif
 
 #include "cpp.h"
+#include "version.h"         // version numbers from autoconf
 #include "error_numbers.h"
 #include "filesys.h"
 #include "parse.h"
@@ -149,6 +150,7 @@ CLIENT_STATE::CLIENT_STATE()
     launched_by_manager = false;
     initialized = false;
     last_wakeup_time = dtime();
+    device_status_time = 0;
 #ifdef _WIN32
     have_sysmon_msg = false;
 #endif
@@ -157,6 +159,10 @@ CLIENT_STATE::CLIENT_STATE()
 void CLIENT_STATE::show_host_info() {
     char buf[256], buf2[256];
 
+    msg_printf(NULL, MSG_INFO,
+        "Host name: %s",
+        host_info.domain_name
+    );
     nbytes_to_string(host_info.m_cache, 0, buf, sizeof(buf));
     msg_printf(NULL, MSG_INFO,
         "Processor: %d %s %s",
@@ -313,10 +319,8 @@ int CLIENT_STATE::init() {
     time_stats.start();
 
     msg_printf(
-        NULL, MSG_INFO, "Starting BOINC client version %d.%d.%d for %s%s",
-        core_client_version.major,
-        core_client_version.minor,
-        core_client_version.release,
+        NULL, MSG_INFO, "Starting BOINC client version %s for %s%s",
+        BOINC_VERSION_STRING,
         get_primary_platform(),
 #ifdef _DEBUG
         " (DEBUG)"
@@ -353,10 +357,6 @@ int CLIENT_STATE::init() {
     parse_account_files();
     parse_statistics_files();
 
-    host_info.get_host_info();
-    set_ncpus();
-    show_host_info();
-
     // check for GPUs.
     //
     for (int j=1; j<coprocs.n_rsc; j++) {
@@ -429,7 +429,7 @@ int CLIENT_STATE::init() {
     // check for app_info.xml file in project dirs.
     // If find, read app info from there, set project.anonymous_platform
     // - this must follow coproc.get() (need to know if GPUs are present)
-    // - this is being done before CPU speed has been read,
+    // - this is being done before CPU speed has been read from state file,
     // so we'll need to patch up avp->flops later;
     //
     check_anonymous();
@@ -444,11 +444,18 @@ int CLIENT_STATE::init() {
     //
     parse_state_file();
 
+    // this follows parse_state_file() since we need to have read
+    // domain_name for Android
+    //
+    host_info.get_host_info();
+    set_ncpus();
+    show_host_info();
+
     // check for app_config.xml files in project dirs
     //
     check_app_config();
 
-    // this needs to go after parse_state_file because
+    // this needs to go after parse_state_file() because
     // GPU exclusions refer to projects
     //
     config.show();
@@ -1381,6 +1388,7 @@ bool CLIENT_STATE::garbage_collect_always() {
                         rp->name
                     );
                 }
+                add_old_result(*rp);
                 delete rp;
                 result_iter = results.erase(result_iter);
                 action = true;
