@@ -640,11 +640,22 @@ int CLIENT_STATE::handle_scheduler_reply(
 
     // show messages from server
     //
+    bool got_notice = false;
     for (i=0; i<sr.messages.size(); i++) {
         USER_MESSAGE& um = sr.messages[i];
-        int prio = (!strcmp(um.priority.c_str(), "notice"))?MSG_SCHEDULER_ALERT:MSG_INFO;
+        int prio = MSG_INFO;
+        if (!strcmp(um.priority.c_str(), "notice")) {
+            prio = MSG_SCHEDULER_ALERT;
+            got_notice = true;
+        }
         msg_printf(project, prio, "%s", um.message.c_str());
     }
+    // if we requested work and didn't get notices,
+    // clear scheduler notices from this project
+    //
+    if (work_fetch.requested_work() && !got_notice) {
+        notices.remove_scheduler_notices(project);
+    }
 
     if (log_flags.sched_op_debug && sr.request_delay) {
         msg_printf(project, MSG_INFO,
@@ -687,6 +698,7 @@ int CLIENT_STATE::handle_scheduler_reply(
         }
     }
 
+#ifdef USE_NET_PREFS
     // see if we have a new venue from this project
     // (this must go AFTER the above, since otherwise
     // global_prefs_source_project() is meaningless)
@@ -704,6 +716,7 @@ int CLIENT_STATE::handle_scheduler_reply(
     if (update_global_prefs) {
         read_global_prefs();
     }
+#endif
 
     // deal with project preferences (should always be there)
     // If they've changed, write to account file,
