@@ -374,6 +374,8 @@ static void handle_set_gpu_mode(GUI_RPC_CONN& grc) {
     grc.mfout.printf("<success/>\n");
 }
 
+// used on Android - get product name and MAC addr from GUI,
+//
 static void handle_set_host_info(GUI_RPC_CONN& grc) {
     while (!grc.xp.get_tag()) {
         if (grc.xp.match_tag("host_info")) {
@@ -1022,12 +1024,11 @@ static void handle_set_global_prefs_override(GUI_RPC_CONN& grc) {
             retval = boinc_delete_file(GLOBAL_PREFS_OVERRIDE_FILE);
         }
     }
-    grc.mfout.printf(
-        "<set_global_prefs_override_reply>\n"
-        "    <status>%d</status>\n"
-        "</set_global_prefs_override_reply>\n",
-        retval
-    );
+    if (retval) {
+        grc.mfout.printf("<status>%d</status>\n", retval);
+    } else {
+        grc.mfout.printf("<success/>\n");
+    }
 }
 
 static void handle_get_cc_config(GUI_RPC_CONN& grc) {
@@ -1072,12 +1073,11 @@ static void handle_set_cc_config(GUI_RPC_CONN& grc) {
             retval = boinc_delete_file(CONFIG_FILE);
         }
     }
-    grc.mfout.printf(
-        "<set_cc_config_reply>\n"
-        "    <status>%d</status>\n"
-        "</set_cc_config_reply>\n",
-        retval
-    );
+    if (retval) {
+        grc.mfout.printf("<status>%d</status>\n", retval);
+    } else {
+        grc.mfout.printf("<success/>\n");
+    }
 }
 
 static void handle_get_notices(GUI_RPC_CONN& grc) {
@@ -1096,6 +1096,10 @@ static void handle_get_notices_public(GUI_RPC_CONN& grc) {
     notices.write(seqno, grc, true);
 }
 
+static void handle_get_old_results(GUI_RPC_CONN& grc) {
+    print_old_results(grc.mfout);
+}
+
 static void handle_get_results(GUI_RPC_CONN& grc) {
     bool active_only = false;
     while (!grc.xp.get_tag()) {
@@ -1185,6 +1189,14 @@ static void handle_report_device_status(GUI_RPC_CONN& grc) {
                 }
             }
             if (!retval) {
+                // if the GUI reported a device name, use it
+                //
+                if (strlen(d.device_name)) {
+                    if (strcmp(d.device_name, gstate.host_info.domain_name)) {
+                        strcpy(gstate.host_info.domain_name, d.device_name);
+                        gstate.set_client_state_dirty("Device name changed");
+                    }
+                }
                 gstate.device_status = d;
                 gstate.device_status_time = gstate.now;
                 grc.mfout.printf("<success/>\n");
@@ -1207,6 +1219,7 @@ int DEVICE_STATUS::parse(XML_PARSER& xp) {
         if (xp.parse_double("battery_temperature_celsius", battery_temperature_celsius)) continue;
         if (xp.parse_bool("wifi_online", wifi_online)) continue;
         if (xp.parse_bool("user_active", user_active)) continue;
+        if (xp.parse_str("device_name", device_name, sizeof(device_name))) continue;
     }
     return ERR_XML_PARSE;
 }
@@ -1260,6 +1273,7 @@ GUI_RPC gui_rpcs[] = {
     GUI_RPC("get_message_count", handle_get_message_count,          false,  false,  true),
     GUI_RPC("get_newer_version", handle_get_newer_version,          false,  false,  true),
     GUI_RPC("get_notices_public", handle_get_notices_public,        false,  false,  true),
+    GUI_RPC("get_old_results", handle_get_old_results,              false,  false,  true),
     GUI_RPC("get_project_status", handle_get_project_status,        false,  false,  true),
     GUI_RPC("get_results", handle_get_results,                      false,  false,  true),
     GUI_RPC("get_screensaver_tasks", handle_get_screensaver_tasks,  false,  false,  true),
