@@ -685,7 +685,7 @@ void use_cpuid(HOST_INFO& host) {
     capabilities[0] = '\0';
     if (hasSSE) strcat(capabilities, "sse ");
     if (hasSSE2) strcat(capabilities, "sse2 ");
-    if (hasSSE3) strcat(capabilities, "sse3 ");
+    if (hasSSE3) strcat(capabilities, "pni ");
     if (has3DNow) strcat(capabilities, "3dnow ");
     if (has3DNowExt) strcat(capabilities, "3dnowext ");
     if (hasMMX) strcat(capabilities, "mmx ");
@@ -1348,7 +1348,31 @@ int HOST_INFO::get_host_info() {
 
 // sysconf not working on OS2
 #if defined(ANDROID)
+    // this should work on most devices
     p_ncpus = sysconf(_SC_NPROCESSORS_CONF);
+    
+    // work around for bug in Android's bionic
+    // format of /sys/devices/system/cpu/present:
+    // 0 : single core
+    // 0-j: j+1 cores (e.g. 0-3 quadcore)
+    FILE* fp;
+    int res, i=-1, j=-1, cpus_sys_path=0;
+    fp = fopen("/sys/devices/system/cpu/present", "r");
+    if(fp) {
+        res = fscanf(fp, "%d-%d", &i, &j);
+        fclose(fp);
+        if(res == 1 && i == 0) {
+            cpus_sys_path = 1;
+        }
+        if(res == 2 && i == 0) {
+            cpus_sys_path = j + 1;
+        }
+    }
+    
+    // return whatever number is greater
+    if(cpus_sys_path > p_ncpus){
+        p_ncpus = cpus_sys_path;
+    }
 #elif defined(_SC_NPROCESSORS_ONLN) && !defined(__EMX__) && !defined(__APPLE__)
     p_ncpus = sysconf(_SC_NPROCESSORS_ONLN);
 #elif defined(HAVE_SYS_SYSCTL_H) && defined(CTL_HW) && defined(HW_NCPU)
